@@ -15,7 +15,7 @@ from yarl import URL
 
 from neuro_sdk import DEFAULT_API_URL, ConfigError
 
-from neuro_cli.formatters.config import ClustersFormatter, QuotaInfoFormatter
+from neuro_cli.formatters.config import ClustersFormatter, QuotaFormatter
 
 from .alias import list_aliases
 from .formatters.config import AliasesFormatter, ConfigFormatter
@@ -33,9 +33,10 @@ async def show(root: Root) -> None:
     """
     Print current settings.
     """
+    cluster_name = root.client.config.cluster_name
     fmt = ConfigFormatter()
     try:
-        jobs_capacity = await root.client.jobs.get_capacity()
+        jobs_capacity = await root.client.jobs.get_capacity(cluster_name=cluster_name)
     except ClientConnectionError:
         jobs_capacity = {}
     root.print(fmt(root.client.config, jobs_capacity))
@@ -55,7 +56,8 @@ async def show_quota(root: Root, user: Optional[str]) -> None:
     """
     Print quota and remaining computation time for active cluster.
     """
-    quotas = await root.client._quota.get(user)
+    username = user or root.client.config.username
+    quotas = await root.client._users.get_quota(username)
     cluster_name = root.client.config.cluster_name
     if cluster_name not in quotas:
         raise ValueError(
@@ -63,7 +65,7 @@ async def show_quota(root: Root, user: Optional[str]) -> None:
             "Please logout and login again."
         )
     cluster_quota = quotas[cluster_name]
-    fmt = QuotaInfoFormatter()
+    fmt = QuotaFormatter()
     root.print(fmt(cluster_quota))
 
 
@@ -234,8 +236,9 @@ async def get_clusters(root: Root) -> None:
     Fetch and display the list of available clusters.
 
     """
-    root.print("Fetch the list of available clusters...", style="dim")
-    await root.client.config.fetch()
+
+    with root.status("Fetching the list of available clusters"):
+        await root.client.config.fetch()
     fmt = ClustersFormatter()
     with root.pager():
         root.print(
@@ -252,8 +255,8 @@ async def switch_cluster(root: Root, cluster_name: Optional[str]) -> None:
     name is omitted (default).
 
     """
-    root.print("Fetch the list of available clusters...", style="dim")
-    await root.client.config.fetch()
+    with root.status("Fetching the list of available clusters"):
+        await root.client.config.fetch()
     if cluster_name is None:
         if not root.tty:
             raise click.BadArgumentUsage(
