@@ -18,7 +18,6 @@ from typing import (
     Iterator,
     List,
     Optional,
-    Sequence,
     Set,
     Tuple,
     Type,
@@ -29,6 +28,7 @@ from typing import (
 
 import click
 import humanize
+from aiohttp import ClientResponseError
 from click.types import convert_type
 from yarl import URL
 
@@ -109,8 +109,12 @@ def _wrap_async_callback(
 
 
 class HelpFormatter(click.HelpFormatter):
-    def write_usage(self, prog: str, args: str = "", prefix: str = "Usage:") -> None:
-        super().write_usage(prog, args, prefix=click.style(prefix, bold=True) + " ")
+    def write_usage(
+        self, prog: str, args: str = "", prefix: Optional[str] = "Usage:"
+    ) -> None:
+        super().write_usage(
+            prog, args, prefix=click.style(prefix or "", bold=True) + " "
+        )
 
     def write_heading(self, heading: str) -> None:
         self.write(
@@ -150,9 +154,9 @@ class NeuroClickMixin:
         args = [i for i in ret if not isinstance(i, click.Option)]
         opts = [i for i in ret if isinstance(i, click.Option)]
 
-        help_names = self.get_help_option_names(ctx)  # type: ignore
+        help_names = set(self.get_help_option_names(ctx))  # type: ignore
 
-        def sort_key(opt: click.Option) -> Tuple[bool, str]:
+        def sort_key(opt: click.Option) -> Tuple[bool, Optional[str]]:
             flag = set(opt.opts) & help_names or set(opt.secondary_opts) & help_names
             return (not flag, opt.name)
 
@@ -207,8 +211,8 @@ class NeuroClickMixin:
 
     def make_context(
         self,
-        info_name: str,
-        args: Sequence[str],
+        info_name: Optional[str],
+        args: List[str],
         parent: Optional[click.Context] = None,
         **extra: Any,
     ) -> Context:
@@ -313,8 +317,8 @@ class Group(NeuroGroupMixin, click.Group):
 
         return decorator
 
-    def list_commands(self, ctx: click.Context) -> Iterable[str]:
-        return self.commands
+    def list_commands(self, ctx: click.Context) -> List[str]:
+        return list(self.commands)
 
     def invoke(self, ctx: click.Context) -> None:
         if not ctx.args and not ctx.protected_args:
@@ -354,7 +358,7 @@ class DeprecatedGroup(NeuroGroupMixin, click.MultiCommand):
     def get_command(self, ctx: click.Context, cmd_name: str) -> Optional[click.Command]:
         return self.origin.get_command(ctx, cmd_name)
 
-    def list_commands(self, ctx: click.Context) -> Iterable[str]:
+    def list_commands(self, ctx: click.Context) -> List[str]:
         return self.origin.list_commands(ctx)
 
 
@@ -423,6 +427,13 @@ JOB_ID_PATTERN = r"job-[0-9a-z]{8}-[0-9a-z]{4}-[0-9a-z]{4}-[0-9a-z]{4}-[0-9a-z]{
 async def resolve_job(
     id_or_name_or_uri: str, *, client: Client, status: Set[JobStatus]
 ) -> str:
+    id, _ = await resolve_job_ex(id_or_name_or_uri, client=client, status=status)
+    return id
+
+
+async def resolve_job_ex(
+    id_or_name_or_uri: str, *, client: Client, status: Set[JobStatus]
+) -> Tuple[str, str]:
     default_user = client.username
     default_cluster = client.cluster_name
     if id_or_name_or_uri.startswith("job:"):
@@ -432,32 +443,35 @@ async def resolve_job(
             cluster_name=default_cluster,
             allowed_schemes=("job",),
         )
-        if uri.host != default_cluster:
-            raise ValueError(f"Invalid job URI: cluster_name != '{default_cluster}'")
+        assert uri.host
+        cluster_name = uri.host
         owner, _, id_or_name = uri.path.lstrip("/").partition("/")
         if not owner:
-            raise ValueError(f"Invalid job URI: missing owner")
+            raise ValueError("Invalid job URI: missing owner")
         if not id_or_name:
-            raise ValueError(
-                f"Invalid job URI: owner='{owner}', missing job-id or job-name"
-            )
+            raise ValueError("Invalid job URI: missing job-id or job-name")
     else:
         id_or_name = id_or_name_or_uri
         owner = default_user
+        cluster_name = default_cluster
 
     # Temporary fast path.
     if re.fullmatch(JOB_ID_PATTERN, id_or_name):
-        return id_or_name
+        return id_or_name, cluster_name
 
     try:
         async for job in client.jobs.list(
-            name=id_or_name, owners={owner}, reverse=True, limit=1
+            name=id_or_name,
+            owners={owner},
+            reverse=True,
+            limit=1,
+            cluster_name=cluster_name,
         ):
             log.debug(f"Job name '{id_or_name}' resolved to job ID '{job.id}'")
-            return job.id
+            return job.id, cluster_name
     except asyncio.CancelledError:
         raise
-    except Exception as e:
+    except ClientResponseError as e:
         log.error(
             f"Failed to resolve job-name {id_or_name_or_uri} resolved as "
             f"name={id_or_name}, owner={owner} to a job-ID: {e}"
@@ -465,7 +479,7 @@ async def resolve_job(
 
     if owner != default_user:
         raise ValueError(f"Failed to resolve job {id_or_name_or_uri}")
-    return id_or_name
+    return id_or_name, cluster_name
 
 
 DISK_ID_PATTERN = r"disk-[0-9a-z]{8}-[0-9a-z]{4}-[0-9a-z]{4}-[0-9a-z]{4}-[0-9a-z]{12}"
@@ -544,7 +558,7 @@ def parse_permission_action(action: str) -> Action:
     try:
         return Action[action.upper()]
     except KeyError:
-        valid_actions = ", ".join([a.value for a in Action])
+        valid_actions = ", ".join(a.value for a in Action)
         raise ValueError(
             f"invalid permission action '{action}', allowed values: {valid_actions}"
         )
@@ -553,6 +567,8 @@ def parse_permission_action(action: str) -> Action:
 def do_deprecated_quiet(
     ctx: click.Context, param: Union[click.Option, click.Parameter], value: Any
 ) -> Any:
+    if ctx.obj is None:
+        return
     if value and not ctx.obj.quiet:
         ctx.obj.verbosity = -2
         click.echo(
